'
' Licensed Materials - Property of IBM
' 5748-XX8
' (c) Copyright International Business Machines Corp. 2006
' All Rights Reserved
' US Government Users Restricted Rights - Use, duplication or disclosure
' restricted by GSA ADP Schedule Contract with IBM Corp.
'
option explicit
'
' Usage: 
'
' fimpipicfg.vbs -host <SPS host> 
'                -port <SPS port> 
'                -use_tcd true | false
'
const HOST_PARAMETER  = "-host"
const PORT_PARAMETER  = "-port"
const TCD_PARAMETER   = "-use_tcd"

' The main line

dim host, port, tcd

host  = getParameterValue(HOST_PARAMETER)
port  = getParameterValue(PORT_PARAMETER)
tcd   = getParameterValue(TCD_PARAMETER)

if isnull(host) or isnull(port) or isnull(tcd) then
        printUsage
else
        performConfig host, port, tcd
end if

'
' Prints the usage of this program
'
sub printUsage
        WScript.Echo "fimpipicfg.vbs -host <SPS host> -port <SPS port> -use_tcd <true | false>"
end sub

'
' Get a parameter value from the command line. Only gets the first instance
' of the value
'
' \param parameter : The named command line parameter
'
' \retval null if the named parameter was not found
'         The parameter value otherwise
'
function getParameterValue (parameter)
        dim index       
        getParameterValue = null
        for index = 0 to WScript.Arguments.Count - 1 step 2
                if WScript.Arguments.Item(index) = parameter then
                        getParameterValue = WScript.Arguments.Item(index + 1)
                        index = WScript.Arguments.Count + 1
                end if
        next
end function

'
' Configure the plug-in by copying the contents of the template file
' into the config file, substituting the actual configuration values
' specified for the placeholders.
'
' \param hostName  : The name of the machine that is running the SPS
' \param hostPort  : The port the SPS is listening on
' \param useTCD    : Whether or not Tivoli Common Directory logging
'                    should be used
'
sub performConfig (hostName, hostPort, useTCD)
        dim fileSystemObj
        dim configFile, templateFile
        dim configFileName, templateFileName, logFileName, logFileDir
        
        const HOST_CONFIG_VALUE      = "host"
        const PORT_CONFIG_VALUE      = "port"
        const LOGFILE_CONFIG_VALUE   = "log-file"
        const FIM_TCD_PRODUCT_CODE   = "FBT"
        
        configFileName   = getBasePath() & "\etc\fimpi.conf"
        templateFileName = configFileName & ".template"
        
        if StrComp(useTCD, "true", vbTextCompare) = 0 then 
                dim tcdLogPath
                tcdLogPath = getTCDLogPath()
                ' If we can't get the TCD common path path then fall back to the FIMPI base path
                if tcdLogPath = "" then
                        logFileDir = getBasePath() & "\log"
                else
                        logFileDir = tcdLogPath & "\" & FIM_TCD_PRODUCT_CODE & "\logs"
                end if
        else
                logFileDir = getBasePath() & "\log"
        end if

        mkdirDashP logFileDir
        logFileName = logFileDir & "\fimpi.log"

        set fileSystemObj = CreateObject("Scripting.FileSystemObject")
        set configFile    = fileSystemObj.CreateTextFile(configFileName, true, false)  ' Overwrite, LCP
        set templateFile  = fileSystemObj.OpenTextFile(templateFileName, 1)            ' Open for reading


        ' This doesn't pay attention to the stanzas. However the values being set 
        ' are unique within the file anyway.
        while not templateFile.AtEndOfStream
                dim rawLine, trimmedLine
                rawLine = templateFile.ReadLine
                trimmedLine = trim(rawLine)
                if instr(trimmedLine, HOST_CONFIG_VALUE) = 1 then
                        configFile.WriteLine(HOST_CONFIG_VALUE & " = " & hostName)
                elseif instr(trimmedLine, PORT_CONFIG_VALUE) = 1 then
                        configFile.WriteLine(PORT_CONFIG_VALUE & " = " & hostPort)
                elseif instr(trimmedLine, LOGFILE_CONFIG_VALUE) = 1 then
                        configFile.WriteLine(LOGFILE_CONFIG_VALUE & " = " & logFileName)
                else
                        configFile.WriteLine(rawLine)
                end if
        wend

end sub

'
' Get the base FIMPI installation directory from the registry
'
' \retval The FIMPI base path as stored in the registry
'
function getBasePath()
        dim objShell
        set objShell = WScript.CreateObject("WScript.Shell")
        
        dim basePath
        basePath = objShell.RegRead("HKLM\Software\IBM\Tivoli Federated Identity Manager\6.1.1.0\WebServerPlugin\BasePath")

        getBasePath = basePath
end function

'
' This function creates the directory specified and all the parent directories
' that don't exist higher than this one, making it equivalent to mkdir -p
'
' \param directory : The directory path to create
'
sub mkdirDashP (directory)
        dim fileSystemObj
        set fileSystemObj = CreateObject("Scripting.FileSystemObject")
        
        dim pathParts, currentPath, currentPart
        
        pathParts = split(directory, "\")
        currentPath = ""
        for each currentPart in pathParts
                currentPath = currentPath & currentPart & "\"
                if not fileSystemObj.FolderExists(currentPath) then
                        fileSystemObj.CreateFolder(currentPath)
                end if
        next

end sub

'
' Gets the Tivoli Common Directory path. If TCD has been configured, then there
' will be a file %PROGRAM FILES%\ibm\tivoli\common\cfg\log.properties that
' contains a value specifying the location of the Tivoli Common Directory. 
' If that file doesn't exist, this function will configure TCD with the default
' path, otherwise it will use the path specified in the TCD.
'
function getTCDLogPath()
        const TCD_CONFIG_VALUE = "tivoli_common_dir" 

        dim objShell, programFilesPath, tcdPropsFolder, tcdPropsFilePath
        set objShell = WScript.CreateObject("WScript.Shell")
        programFilesPath = objShell.RegRead("HKLM\Software\Microsoft\Windows\CurrentVersion\ProgramFilesDir")
        tcdPropsFolder = programFilesPath & "\ibm\tivoli\common\cfg"
        tcdPropsFilePath = tcdPropsFolder & "\log.properties"
        
        dim fileSystemObj, tcdPropsFile
        set fileSystemObj = CreateObject("Scripting.FileSystemObject")
        
        if not fileSystemObj.FileExists(tcdPropsFilePath) then
                mkdirDashP tcdPropsFolder
                set tcdPropsFile = fileSystemObj.CreateTextFile(tcdPropsFilePath, true, false)
                tcdPropsFile.WriteLine("#")
                tcdPropsFile.WriteLine(TCD_CONFIG_VALUE & " = " & programFilesPath & "\ibm\tivoli\common\")
                tcdPropsFile.Close()
        end if

        ' This should now succeed since we will have create the file if necessary.      
        set tcdPropsFile = fileSystemObj.OpenTextFile(tcdPropsFilePath, 1)       ' Open for reading

        getTCDLogPath = ""

        while not tcdPropsFile.AtEndOfStream
                dim rawLine, trimmedLine
                rawLine = tcdPropsFile.ReadLine()
                trimmedLine = trim(rawLine)
                
                if instr(trimmedLine, TCD_CONFIG_VALUE) = 1 then
                        dim lineParts, value
                        lineParts = split(trimmedLine, "=")
                        value = trim(lineParts(1))
                        getTCDLogPath = value
                end if
        wend
        
end function
