# @(#)87  1.5 src/cmdline/staging/scripts/configuration_parameters.py, amws.cmdline, fim611, 060808b 5/4/06 20:19:56
# (C) Copyright International Business Machines Corporation 2005. All rights
# reserved.  U.S. Government Users Restricted Rights -- Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

from fim_base import print_dictionary, FIM_TRUE, FIM_FALSE
from sys import stdin
import saml20_utils

###################################################
# The file provides data and functions for determining the configuration
# parameters of federations and partners based on role/protocol combinations.
###################################################
 
###################################################
# General federation properties
#
fed=["Description","DisplayName"]

###################################################
# SAML 1.0 and 1.1 Configuration Parameters
#

# SAML 1.x self configuration parameters
saml1x_self=["ProviderId", "SignonEndpoint", "SigningKeyIdentifier"]

# SAML 1.x self identity provider (IP) configuration parameters
saml1x_self_ip=["ArtifactCacheLifetime",  \
"ArtifactResolutionService", "AllowIBMProtocolExtension", \
"SoapClientBasicAuth", "SoapClientBasicAuthUsername","SoapClientBasicAuthPassword",  \
"SoapServerKeyIdentifier", "SoapServerCertAuth", \
"SoapClientKeyIdentifier", "SoapClientCertAuth"]
saml1x_self_ip_other=["SignArtifactResponse"]
saml1x_self_ip_token={\
"com.tivoli.am.fim.sts.saml.1.0.assertion.pretime.valid":"SAML10AssertionPretimeValid",\
"com.tivoli.am.fim.sts.saml.1.0.assertion.posttime.valid":"SAML10AssertionPosttimeValid",\
"com.tivoli.am.fim.sts.saml.1.0.assertion.issuer":"SAML10AssertionIssuer",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.pretime.valid":"SAML11AssertionPretimeValid",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.posttime.valid":"SAML11AssertionPosttimeValid",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.issuer":"SAML11AssertionIssuer"}

# SAML 1.x self service provider (SP) configuration parameters
saml1x_self_sp=[]
saml1x_self_sp_other=["SignArtifactRequest", "UseArtifactForSSO"]
saml1x_self_sp_token={\
"com.tivoli.am.fim.sts.saml.1.1.assertion.replay.validation":"SAML11AssertionReplayValidation"}

# SAML 1.x partner configuration parameters: Self=IP, Partner=SP
saml1x_partner_ip=["ProviderId", "SignonEndpoint", "ValidateKeyIdentifier"]
saml1x_partner_ip_other=["ValidateArtifactRequest", "UseArtifactForSSO"]
saml1x_partner_ip_token={\
"com.tivoli.am.fim.sts.saml.1.0.assertion.keystore.alias":"SAML10AssertionKeystoreAlias", \
"com.tivoli.am.fim.sts.saml.1.0.assertion.attribute.types":"SAML10AssertionAttributeTypes",\
"com.tivoli.am.fim.sts.saml.1.0.assertion.sign":"SAML10AssertionSign",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.keystore.alias":"SAML11AssertionKeystoreAlias",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.attribute.types":"SAML11AssertionAttributeTypes",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.sign":"SAML11AssertionSign"}

# SAML 1.x partner configuration parameters: Self=SP, Partner=IP
saml1x_partner_sp=["ProviderId", "SignonEndpoint", \
"ArtifactResolutionService", "ValidateKeyIdentifier", "ArtifactCacheLifetime",\
"SoapClientBasicAuth", "SoapClientBasicAuthUsername","SoapClientBasicAuthPassword",  \
"SoapServerKeyIdentifier", "SoapServerCertAuth", \
"SoapClientKeyIdentifier", "SoapClientCertAuth"]
saml1x_partner_sp_other=["ValidateArtifactResponse"]
saml1x_partner_sp_token={\
"com.tivoli.am.fim.sts.saml.1.0.assertion.keystore.alias":"SAML10AssertionKeystoreAlias",\
"com.tivoli.am.fim.sts.saml.1.0.assertion.verify.signatures":"SAML10AssertionVerifySignatures",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.keystore.alias":"SAML11AssertionKeystoreAlias",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.verify.signatures":"SAML11AssertionVerifySignatures"}

###################################################
# SAML 2.0 Configuration Parameters
#
# SAML 2.0 self configuration parameters
succinct_id = "SourceId" # not yet supported
saml20=["ProviderId", "EncryptionKeyIdentifier", "EncryptionKeyTransportAlgorithm"]
saml20_bool=["ValidateAllSamlMessages"]
saml20_self=["CommonDomainName", "CommonDomainServiceHost", \
"ArtifactLifetime", "MessageValidTime", "ProviderId", "SessionTimeout", \
"SigningKeyIdentifier"]
saml20_self_bool=["DoIdentityProviderIntroduction","EnhancedClientProxyEnabled", \
"AllowConfigOverrides", "SignAllSamlMessages", "SignArtifactRequest", \
"SignArtifactResponse", "SignLogoutRequest", "SignLogoutResponse", \
"SignNameIdManagementRequest", "SignNameIdManagementResponse"]
saml20_partner=["ValidateKeyIdentifier", "BlockEncryptionAlgorithm", \
"SoapRequestClientBasicAuthPassword", "SoapRequestClientBasicAuthUser", \
"SoapRequestClientCertAuthKeyId", "SoapRequestServerCertAuthKeyId", \
"SignAssertion"]
saml20_partner_bool=["EncryptAllAttributes", "EncryptAssertion","EncryptNameIdentifier", \
"ShouldUseClientBasicAuth", "ShouldUseSoapClientCertAuth", "ShouldUseSoapServerCertAuth", \
"ValidateArtifactRequest","ValidateArtifactResponse"]

# SAML 2.0 self identity provider (IP) configuration parameters
saml20_self_ip=["CommonDomainCookieLifetime"]
saml20_self_ip_bool=["NeedConsentToFed", "SignAuthnResponse",\
"WantAuthnRequestsSigned", "ValidateAllSamlMessages"]
saml20_self_ip_token={\
"com.tivoli.am.fim.sts.saml.2.0.assertion.pretime.valid":"SAML20AssertionPretimeValid",\
"com.tivoli.am.fim.sts.saml.2.0.assertion.posttime.valid":"SAML20AssertionPosttimeValid",\
"com.tivoli.am.fim.sts.saml.2.0.assertion.issuer":"SAML20AssertionIssuer"}

# SAML 2.0 self service provider (SP) configuration parameters
saml20_self_sp=[]
saml20_self_sp_bool=["SignArtifactRequest", "IsPassive",\
"ShouldForceAuthn", "SignAuthnRequest", "ValidateAuthnRequest", \
"ValidateAllSamlMessages", "WantAssertionsSigned"]
saml20_self_sp_token={}

# SAML 2.0 partner configuration parameters: Self=IP, Partner=SP
saml20_partner_ip=["SessionNotOnOrAfter"]
saml20_partner_ip_bool=[]
saml20_partner_ip_token={\
"com.tivoli.am.fim.sts.saml.2.0.assertion.attribute.types":"SAML20AssertionAttributeTypes"}

# SAML 2.0 partner configuration parameters: Self=SP, Partner=IP
saml20_partner_sp=["DefaultTargetURL"]
saml20_partner_sp_bool=["SignAuthnRequest", "ValidateAuthnResponse", \
"ValidateAllSamlMessages"]
saml20_partner_sp_token={\
"com.tivoli.am.fim.sts.saml.2.0.onetime.nameid.user":"SAML20OnetimeNameId.User"}

###################################################
# Liberty 1.1 and 1.2 Configuration Parameters
#

# Liberty self configuration parameters
#"FedTerminationNotificationProtocolProfile",\
lib1x_common=["ProviderId", "SoapEndpoint",  \
"FedTerminationServiceReturnURL", "FedTerminationServiceURL", \
"RegisterNameIdentifierProtocolProfile", \
"RegisterNameIdentifierServiceReturnURL", "RegisterNameIdentifierServiceReturnURL", \
"RegisterNameIdentifierServiceURL","SingleLogoutServiceReturnURL", "SingleLogoutServiceURL", \
"SingleLogoutProtocolProfile", "LibMessageValidTime"]

lib1x_self = lib1x_common + ["SigningKeyIdentifier", "SoapEndpoint"]
lib1x_common_other = ["ShouldSignLibMsgs"] 

# Liberty 1.x self identity provider (IP) configuration parameters
lib1x_self_ip = lib1x_self + ["ArtifactLifetime",  "SingleSignOnServiceURL",\
"IPIntroductionEndpoint", "DoIPIntroduction","CommonDomain", "CommonDomainServiceHost", \
"CommonDomainCookieLifetime"]
lib1x_self_ip_other = ["NeedConsentToFed","UseHttpGetLogout"]
lib1x_self_ip_token={\
"com.tivoli.am.fim.sts.liberty.1.1.assertion.pretime.valid":"Lib11AssertionPretimeValid",\
"com.tivoli.am.fim.sts.liberty.1.1.assertion.posttime.valid":"Lib11AssertionPosttimeValid",\
"com.tivoli.am.fim.sts.liberty.1.2.assertion.pretime.valid":"Lib12AssertionPretimeValid",\
"com.tivoli.am.fim.sts.liberty.1.2.assertion.posttime.valid":"Lib12AssertionPosttimeValid"}

# Liberty 1.x self identity provider (IP) configuration parameters
lib1x_self_sp = lib1x_self + ["AssertionConsumerServiceURL"]
lib1x_self_sp_other = ["IsPassive","ShouldForceAuthn","UseArtifactProfileForSSO"]
lib1x_self_sp_token={}

# Liberty 1.x common partner parameters
lib1x_partner_common = lib1x_common + ["SoapRequestClientBasicAuthPassword",\
"SoapRequestClientBasicAuthUser", "SoapRequestClientCertAuthKeyId", \
"SoapRequestServerCertAuthKeyId", "ValidateKeyIdentifier" ]
lib1x_partner_common_other = ["ShouldUseSoapServerCertAuth", \
"ShouldUseSoapClientCertAuth", "ShouldUseClientBasicAuth", "NeedSignedLibMsgs"]

# Liberty 1.x partner configuration parameters: Self=IP, Partner=SP
lib1x_partner_ip = lib1x_partner_common + ["AssertionConsumerServiceURL"]
lib1x_partner_ip_other = lib1x_partner_common_other + ["IsPassive","ShouldForceAuthn",\
"UseArtifactProfileForSSO"]
lib1x_partner_ip_token={\
"com.tivoli.am.fim.sts.liberty.1.1.assertion.attribute.types":"Lib11AssertionAttributeTypes",\
"com.tivoli.am.fim.sts.liberty.1.2.assertion.attribute.types":"Lib12AssertionAttributeTypes"}

# Liberty 1.x partner configuration parameters: Self=SP, Partner=IP
lib1x_partner_sp = lib1x_partner_common + ["SingleSignOnServiceURL"] 
lib1x_partner_common_other = ["ShouldUseSoapServerCertAuth", \
"ShouldUseSoapClientCertAuth", "ShouldUseClientBasicAuth", "NeedSignedLibMsgs"]
lib1x_partner_sp_other = lib1x_partner_common_other +["NeedConsentToFed"]
lib1x_partner_sp_token={}
lib12_partner_sp_token = {\
"com.tivoli.am.fim.sts.liberty.1.2.onetime.nameid.user":"Lib12OnetimeNameidUser"}


###################################################
# WS-Federation Configuration Parameters
#

# WS-Federation self configuration parameters
wsfed_self=["Realm", "Endpoint"]
wsfed_self_ip_token={\
"com.tivoli.am.fim.sts.saml.1.1.assertion.pretime.valid":"SAML11AssertionPretimeValid",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.posttime.valid":"SAML11AssertionPosttimeValid",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.issuer":"SAML11AssertionIssuer"}

wsfed_self_sp_token={\
"com.tivoli.am.fim.sts.saml.1.1.assertion.replay.validation":"SAML11AssertionReplayValidation"}

# WS-Federation partner configuration parameters
wsfed_partner=wsfed_self
wsfed_partner_ip_token={\
"com.tivoli.am.fim.sts.saml.1.1.assertion.keystore.alias":"SAML11AssertionKeystoreAlias",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.attribute.types":"SAML11AssertionAttributeTypes",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.sign":"SAML11AssertionSign"}

wsfed_partner_sp_token={\
"com.tivoli.am.fim.sts.saml.1.1.assertion.keystore.alias":"SAML11AssertionKeystoreAlias",\
"com.tivoli.am.fim.sts.saml.1.1.assertion.verify.signatures":"SAML11AssertionVerifySignatures"}

###################################################
# General utility fuctions
#
#
def prepend_gset(props, get_or_set):
    # prepends string "get" or "set" onto each string in the props list
    # returns a dictionary of property/method pairs
    m={}
    for p in props:
        m[p] = get_or_set + p
    return m

def lower_case(props):
    # makes first letter of each string in the props list lower case
    # returns a dictionary of property/method pairs
    m={}
    for p in props:
        m[p] = p[0].lower()+p[1:]
    return m

def write_header(f):
    f.write("# @(#)87  1.5 src/cmdline/staging/scripts/configuration_parameters.py, amws.cmdline, fim611, 060808b 5/4/06 20:19:56\n")
    f.write("# (C) Copyright International Business Machines Corporation 2005. All rights\n")
    f.write("# reserved.  U.S. Government Users Restricted Rights -- Use, duplication or\n")
    f.write("# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.\n")
    f.write("#\n")
    f.write("# This properties file contains the federation properties organized by\n")
    f.write("# role (IP or SP) and whether the entity is a parnter or a federation.\n")
    f.write("# To use this file, locate the appropriate section, uncomment the \n")
    f.write("# properties you would like to set, and assign them a value. \n")
    f.write("# See the examples directory for example settings.  When the properties \n")
    f.write("# have been set, use this file as input to the FIM staging tools.\n")

def write_props(f, props):
    props.sort()
    done = []
    for p in props:
        if done.count(p):
            break
        done.append(p)
        f.write("#%s=\n"%p)

def write_separator(f):
    f.write("\n")
    f.write("###########\n")
    
######################
# SAML 1.x Utilities
#

# Creates a template properties file for this SSO protocol
def create_saml1x_file(filename):
    f = open(filename,"w")
    write_header(f)
    write_separator(f)
    f.write("# General federation properties\n")
    write_props(f, fed)
    write_separator(f)
    f.write("# SAML 1.x properties for identity providers\n")
    f.write("# Federation properties (self=IP)\n")
    write_props(f, saml1x_self + saml1x_self_ip + saml1x_self_ip_other + saml1x_self_ip_token.values())
    f.write("\n# Partner properties (self=IP, partner=SP)\n")
    write_props(f, saml1x_partner_ip + saml1x_partner_ip_other + saml1x_partner_ip_token.values())
    write_separator(f)
    f.write("# SAML 1.x properties for service providers\n")
    f.write("# Federation properties (self=SP)\n")
    write_props(f, saml1x_self + saml1x_self_sp_other + saml1x_self_sp_token.values())
    f.write("\n# Partner properties (self=SP, partner=IP)\n")
    write_props(f, saml1x_partner_sp + saml1x_partner_sp_other + saml1x_partner_ip_token.values())
    f.close()

# Filters on get or set    
def saml1x_methods(gset_props, other_props, get_or_set):
    if get_or_set=="get":
        methods = prepend_gset(gset_props, get_or_set)
        methods.update(lower_case(other_props))
        return methods
    elif get_or_set=="set":
        return prepend_gset(gset_props + other_props, get_or_set)

# Filters on role and whether partner methods are requested    
def get_saml1x_methods(role, isPartner, get_or_set):
    if role=="ip" and not isPartner:
        gset_props = fed + saml1x_self + saml1x_self_ip
        other_props = saml1x_self_ip_other
        return saml1x_methods(gset_props, other_props, get_or_set)
    if role=="sp" and not isPartner:
        gset_props = fed + saml1x_self
        other_props = saml1x_self_sp_other
        return saml1x_methods(gset_props, other_props, get_or_set)
    if role=="ip" and isPartner:
        gset_props = fed + saml1x_partner_ip
        other_props = saml1x_partner_ip_other
        return saml1x_methods(gset_props, other_props, get_or_set)
    if role=="sp" and isPartner:
        gset_props = fed + saml1x_partner_sp
        other_props = saml1x_partner_sp_other
        return saml1x_methods(gset_props, other_props, get_or_set)
    return None

######################
# SAML 2.0 Utilities
#

# Creates a template properties file for this SSO protocol
def create_saml20_file(filename):
    f = open(filename,"w")
    write_header(f)
    write_separator(f)
    f.write("# General federation properties\n")
    write_props(f, fed)
    write_separator(f)
    f.write("# SAML 2.0 properties for identity providers\n")
    f.write("# Federation properties (self=IP)\n")
    write_props(f, saml20 + saml20_self + saml20_self_bool + saml20_self_ip + \
        saml20_self_ip_bool + saml20_self_ip_token.values())
    write_props(f, saml20_utils.get_saml20_supported_profiles("ip", FIM_FALSE))
    f.write("\n# Partner properties (self=IP, partner=SP)\n")
    write_props(f, saml20 + saml20_partner + saml20_partner_bool + \
        saml20_partner_ip + saml20_partner_ip_bool + saml20_partner_ip_token.values())
    write_props(f, saml20_utils.get_saml20_supported_profiles("ip", FIM_TRUE))
    write_separator(f)
    f.write("# SAML 2.0 properties for service providers\n")
    f.write("# Federation properties (self=SP)\n")
    write_props(f, saml20 + saml20_self + saml20_self_bool + saml20_self_sp + \
        saml20_self_sp_bool + saml20_self_sp_token.values())
    write_props(f, saml20_utils.get_saml20_supported_profiles("sp", FIM_FALSE))
    f.write("\n# Partner properties (self=SP, partner=IP)\n")
    write_props(f, saml20 + saml20_partner + saml20_partner_bool + \
        saml20_partner_sp + saml20_partner_sp_bool + saml20_partner_ip_token.values())
    write_props(f, saml20_utils.get_saml20_supported_profiles("sp", FIM_TRUE))
    f.close()

# Filters on get or set    
def saml20_methods(gset_props, bool_props, get_or_set):
    if get_or_set=="get":
        methods = prepend_gset(gset_props, get_or_set)
        methods.update(lower_case(bool_props))
        return methods
    elif get_or_set=="set":
        return prepend_gset(gset_props + bool_props, get_or_set)

# Filters on role and whether partner methods are requested    
def get_saml20_methods(role, isPartner, get_or_set):
    if role=="ip" and not isPartner:
        gset_props = fed + saml20 + saml20_self + saml20_self_ip
        bool_props = saml20_self_bool + saml20_self_ip_bool
        return saml20_methods(gset_props, bool_props, get_or_set)
    if role=="sp" and not isPartner:
        gset_props = fed + saml20 + saml20_self
        bool_props = saml20_self_bool + saml20_self_sp_bool
        return saml20_methods(gset_props, bool_props, get_or_set)
    if role=="ip" and isPartner:
        gset_props = fed + saml20 + saml20_partner_ip
        bool_props = saml20_partner_bool + saml20_partner_ip_bool
        return saml20_methods(gset_props, bool_props, get_or_set)
    if role=="sp" and isPartner:
        gset_props = fed + saml20 + saml20_partner_sp
        bool_props = saml20_partner_bool + saml20_partner_sp_bool
        return saml20_methods(gset_props, bool_props, get_or_set)
    return None

######################
# Liberty 1.x Utilities
#
# Creates a template properties file for this SSO protocol
def create_lib1x_file(filename):
    f = open(filename,"w")
    write_header(f)
    write_separator(f)
    f.write("# General federation properties\n")
    write_props(f, fed)
    write_separator(f)
    f.write("# Liberty properties for identity providers\n")
    f.write("# Federation properties (self=IP)\n")
    write_props(f, lib1x_self_ip + lib1x_self_ip_other + lib1x_self_ip_token.values())
    f.write("\n# Partner properties (self=IP, partner=SP)\n")
    write_props(f, lib1x_partner_ip + lib1x_partner_ip_other + lib1x_partner_ip_token.values())
    write_separator(f)
    f.write("# Liberty properties for service providers\n")
    f.write("# Federation properties (self=SP)\n")
    write_props(f, lib1x_self_sp_other + lib1x_self_sp_token.values())
    f.write("\n# Partner properties (self=SP, partner=IP)\n")
    write_props(f, lib1x_partner_sp + lib1x_partner_sp_other + lib1x_partner_ip_token.values())
    f.close()

# Filters on get or set
def lib1x_methods(gset_props, other_props, get_or_set):
    if get_or_set=="get":
        methods = prepend_gset(gset_props, get_or_set)
        methods.update(lower_case(other_props))
        return methods
    elif get_or_set=="set":
        return prepend_gset(gset_props + other_props, get_or_set)

# Filters on role and whether partner methods are requested
def get_lib1x_methods(role, isPartner, get_or_set):
    if role=="ip" and not isPartner:
        gset_props = fed + lib1x_self_ip
        other_props = lib1x_common_other + lib1x_self_ip_other
        return lib1x_methods(gset_props, other_props, get_or_set)
    if role=="sp" and not isPartner:
        gset_props = fed + lib1x_self_sp
        other_props = lib1x_common_other + lib1x_self_sp_other
        return lib1x_methods(gset_props, other_props, get_or_set)
    if role=="ip" and isPartner:
        gset_props = fed + lib1x_partner_ip
        other_props = lib1x_partner_ip_other
        return lib1x_methods(gset_props, other_props, get_or_set)
    if role=="sp" and isPartner:
        gset_props = fed + lib1x_partner_sp
        other_props = lib1x_partner_sp_other
        return lib1x_methods(gset_props, other_props, get_or_set)
    return None

######################
# WS-Fedederation Utilities
#

# Creates a template properties file for this SSO protocol
def create_wsfed_file(filename):
    f = open(filename,"w")
    write_header(f)
    write_separator(f)
    f.write("# General federation properties\n")
    write_props(f, fed)
    write_separator(f)
    f.write("# WS-Federation properties for identity providers\n")
    f.write("# Federation properties (self=IP)\n")
    write_props(f, fed + wsfed_self + wsfed_self_ip_token.values())
    f.write("\n# Partner properties (self=IP, partner=SP)\n")
    write_props(f, fed + wsfed_partner)
    write_separator(f)
    f.write("# WS-Federation properties for service providers\n")
    f.write("# Federation properties (self=SP)\n")
    write_props(f, fed + wsfed_self + wsfed_self_sp_token.values())
    f.write("\n# Partner properties (self=SP, partner=IP)\n")
    write_props(f, fed + wsfed_self + wsfed_partner_sp_token.values())
    f.close()

# Filters on role and whether partner methods are requested
def get_wsfed_methods(role, isPartner, get_or_set):
    if role=="ip" and not isPartner:
        gset_props = fed + wsfed_self
        return prepend_gset(gset_props, get_or_set)
    if role=="sp" and not isPartner:
        gset_props = fed + wsfed_self
        return prepend_gset(gset_props, get_or_set)
    if role=="ip" and isPartner:
        gset_props = fed + wsfed_partner
        return prepend_gset(gset_props, get_or_set)
    if role=="sp" and isPartner:
        gset_props = fed + wsfed_partner
        return prepend_gset(gset_props, get_or_set)
    return None

########
# get_methods
#
# Returns a list of method names from the ConfigurationParameters class. 
# The list of methods depends on the given federation role,
# protocol, whether entity is a partner, and whether the property needs
# to be get or set.
#
# The list of methods will then be used by other functions to get and
# set federation properties by evaluating (using Jython eval()) the methods
# during execution of the scritpts.
########

def get_methods(fed_role, fed_protocol, isPartner, get_or_set):
    if (fed_protocol=="SAML1_0" or fed_protocol=="SAML1_1"):
        return get_saml1x_methods(fed_role, isPartner, get_or_set)
    if (fed_protocol=="SAML2_0"):
        return get_saml20_methods(fed_role, isPartner, get_or_set)
    if (fed_protocol=="LBTY1_1"):
        return get_lib1x_methods(fed_role, isPartner, get_or_set)
    if (fed_protocol=="LBTY1_2"):
        return get_lib1x_methods(fed_role, isPartner, get_or_set)
    if (fed_protocol=="WSFED"):
        return get_wsfed_methods(fed_role, isPartner, get_or_set)

########
# get_token_dictionary
#
# Returns a dictionary of token properties given federation role,
# protocol, and whether entity is a partner.
########

def get_token_dictionary(fed_role, fed_protocol, isPartner):
    if (fed_protocol=="SAML1_0" or fed_protocol=="SAML1_1"):
        if fed_role=="ip" and not isPartner:
            return saml1x_self_ip_token
        if fed_role=="sp" and not isPartner:
            return saml1x_self_sp_token
        if fed_role=="ip" and isPartner:
            return saml1x_partner_ip_token
        if fed_role=="sp" and isPartner:
            return saml1x_partner_sp_token
    if (fed_protocol=="SAML2_0"):
        if fed_role=="ip" and not isPartner:
            return saml20_self_ip_token
        if fed_role=="sp" and not isPartner:
            return saml20_self_sp_token
        if fed_role=="ip" and isPartner:
            return saml20_partner_ip_token
        if fed_role=="sp" and isPartner:
            return saml20_partner_sp_token
    if (fed_protocol=="LBTY1_1"):
        if fed_role=="ip" and not isPartner:
            return lib1x_self_ip_token
        if fed_role=="sp" and not isPartner:
            return lib1x_self_sp_token
        if fed_role=="ip" and isPartner:
            return lib1x_partner_ip_token
        if fed_role=="sp" and isPartner:
            return lib1x_partner_sp_token
    if (fed_protocol=="LBTY1_2"):
        if fed_role=="ip" and not isPartner:
            return lib1x_self_ip_token
        if fed_role=="sp" and not isPartner:
            return lib1x_self_sp_token
        if fed_role=="ip" and isPartner:
            return lib1x_partner_ip_token
        if fed_role=="sp" and isPartner:
            return lib12_partner_sp_token
    if (fed_protocol=="WSFED"):
        if fed_role=="ip" and not isPartner:
            return wsfed_self_ip_token
        if fed_role=="sp" and not isPartner:
            return wsfed_self_sp_token
        if fed_role=="ip" and isPartner:
            return wsfed_partner_ip_token
        if fed_role=="sp" and isPartner:
            return wsfed_partner_sp_token

if __name__ == 'main' or __name__ == '__main__':
    etc_dir = "../etc"
    create_saml1x_file(etc_dir + "/saml1x.properties")
    create_saml20_file(etc_dir + "/saml20.properties")
    create_lib1x_file(etc_dir + "/lib1x.properties")
    create_wsfed_file(etc_dir + "/wsfed.properties")
    protocols = ["SAML2_0","SAML1_0", "SAML1_1", "LBTY1_1", "LBTY1_2", "WSFED"]
    roles = ["ip","sp"]
    partners = [FIM_FALSE, FIM_TRUE]
    gsets = ["get", "set"]
    for protocol in protocols:
        for role in roles:
            for partner in partners:
                for gset in gsets:
                    print "\nProperty=Method for (role=%s, protocol=%s, partner=%i, set_or_get=%s)"\
                    %(role,protocol,partner,gset)
                    print "--------------------------------------------------------------------------"
                    d = get_methods(role,protocol, partner,gset)
                    print_dictionary(d)
                    # Uncomment next line if you just want to go once through loop
                    #raise SystemExit

